const util = require('../../utils/util');
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        navbarHeight: 0,
        scrollTop: 0,
        //轮播
        currentSwiper: 0,
        //选项卡
        tabActiveId: 0,
        //弹窗
        isShow: false,
        isLogin: false,
        isLoginShow: false,
        code: '',
        banner: [],
        category: [],
        list: [],
        showtimes: 0
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        this.setData({
            navbarHeight: util.getNavbarHeight(),
        })
        wx.setNavigationBarColor({
            frontColor: '#ffffff',
            backgroundColor: '#ffffff',
        })

        let element_session_key = app.db.get('element_session_key')
        if (element_session_key) {
            this.setData({
                isLogin: true
            })
        }

        if (options.hasOwnProperty('scene')) {
            let scene = decodeURIComponent(options.scene);
            app.db.set('element_invite_id',scene)
        } else {
            if (options.hasOwnProperty('pid')) {
                app.db.set('element_invite_id',options.pid)
            }
        }

        this.getBanner()
        this.getCategory()
        this.getIndexServiceList()
        this.subscribeMessage()
    },

    onShow: function () {
        let element_session_key = app.db.get('element_session_key'), showtimes = this.data.showtimes
        if (element_session_key) {
            if (!this.data.isLogin) {
                this.setData({
                    isLogin: true
                })
            }
            if (this.data.isLoginShow) {
                this.setData({
                    isLoginShow: false
                })
            }
            if (showtimes == 0) {
                this.setData({
                    isShow: true,
                    showtimes: 1
                })
            }
        } else {
            this.setData({
                isLogin: false
            })
        }
        this.getCategory()
        this.getIndexServiceList()
    },

    //获取顶部轮播图
    getBanner: function () {
        let page = this
        app.api.getIndexBanner('', function (res) {
            if (res.code > 0) {
                page.setData({
                    banner: res.data
                })
            } else {
                wx.showToast({
                  title: res.msg,
                  icon: 'none'
                })
            }
        })
    },

    //获取分类
    getCategory: function () {
        let page = this
        app.api.getIndexCategory("", function (res) {
            if (res.code > 0) {
                page.setData({
                    category: res.data
                })
            } else {
                wx.showToast({
                  title: res.msg,
                  icon: 'none'
                })
            }
        })
    },

    //获取服务列表
    getIndexServiceList: function () {
        let page = this
        app.api.getIndexServiceList({}, function (res) {
            if (res.code > 0) {
                page.setData({
                    list: res.data
                })
            } else {
                wx.showToast({
                  title: res.msg,
                  icon: 'none'
                })
            }
        })
    },
    //
    onPageScroll(e) {
        this.setData({
            scrollTop: e.scrollTop,
        });
    },

    //swiper内容左右滑动切换触发
    swiperChange(e) {
        const current = e.detail.current;
        this.setData({
            currentSwiper: current, // 更新当前选中
        });
    },
    // 选项卡
    switchNav(e) {
        const d = e.currentTarget.dataset;
        this.setData({
            tabActiveId: d.id
        })
    },
    /**
     * 弹窗
     */
    showWindow() {
        this.setData({
            isShow: true
        })
    },
    hideWindow() {
        this.setData({
            isShow: false
        })
    },
    //跳转服务详情
    productDetails(e) {
        if (!this.data.isLogin) {
            this.setData({
                isLoginShow: true
            })
            return
        }
        wx.navigateTo({
            url: '../product-details/product-details?id='+e.currentTarget.dataset.id,
        })
    },
    //跳转更多分类
    moreCategories(e) {
        if (!this.data.isLogin) {
            this.setData({
                isLoginShow: true
            })
            return
        }
        wx.navigateTo({
            url: '../more-categories/more-categories?cate_id='+e.currentTarget.dataset.id,
        })
    },
    //跳转搜索页面
    search() {
        if (!this.data.isLogin) {
            this.setData({
                isLoginShow: true
            })
            return
        }
        wx.navigateTo({
            url: '../search/search',
        })
    },

    //隐藏授权弹窗
    hideEmpower: function () {
        this.setData({
            isLoginShow: false
        })
    },

    /**
     * 获取登录code
     */
    getCode: function () {
        let page = this
        wx.login({
            success: function (res) {
                if (res.code) {
                    page.setData({
                        code: res.code
                    })
                } else {
                    wx.showToast({
                        title: '登录失败',
                        icon: 'none'
                    })
                }
            },
            fail: function () {
                wx.showToast({
                    title: '登录失败',
                    icon: 'none'
                })
            }
        })
    },

    //授权获取用户信息
    getUserProfile: function () {
        let page = this, invite_id = app.db.get('element_invite_id'), pid = invite_id ? invite_id : 0
        page.getCode()
        page.setData({
            isLoginShow: false
        })
        wx.getUserProfile({
            desc: '授权登录后可操作',
            success(res) {
                let nickName = res.userInfo.nickName, avatarUrl = res.userInfo.avatarUrl
                app.api.login({name: nickName, headimg: avatarUrl, code: page.data.code, pid: pid}, function (response) {  
                    if (response.code > 0) {
                        page.setData({
                            isLogin: true
                        })
                        app.db.set('element_session_key',response.data, true)
                        app.db.del('element_invite_id')
                        if (!app.db.get('element_user_id')) {
                            page.getUserInfo()
                        }
                    } else {
                        wx.showToast({
                          title: response.msg,
                          icon: 'none'
                        })
                    }
                })
            },
            fail(res) {
                wx.showToast({
                    title: '获取用户信息失败',
                    icon: 'none'
                })
            }
        })
    },

    /**
     * 获取用户信息
     */
    getUserInfo: function () {
        let page = this
        app.api.getUserInfo({}, function (res) {
            if (res.code > 0) {
                if (res.data.hasOwnProperty('id')) {
                    app.db.set('element_user_id', res.data.id)
                    page.setData({
                        isShow: true,
                        showtimes: 1
                    })
                }
            }
        })
    },


    goheight: function () {

    },
    /**
     * 订阅消息
     */
    subscribeMessage: function () {
        let page = this
        wx.showModal({
          title: '提示',
          content: '为了给您推送相关信息，小程序需要您订阅消息',
          confirmText: '同意',
          cancelText: '拒绝',
          confirmColor: '#415BEB',
          success(res) {
              if (res.confirm) {
                wx.requestSubscribeMessage({
                  tmplIds: ['5-Ewwnl9BXvgzAQtWJzuV_fXWTh6x0z2WAv5I3o-jlM'],
                  success(res_) {
                      console.log(res_)
                      if (res_.errMsg == "requestSubscribeMessage:ok") {
                        if (res_.hasOwnProperty("5-Ewwnl9BXvgzAQtWJzuV_fXWTh6x0z2WAv5I3o-jlM")) {
                            if (res_['5-Ewwnl9BXvgzAQtWJzuV_fXWTh6x0z2WAv5I3o-jlM'] == "accept") {
                                wx.showToast({
                                  title: '订阅成功',
                                })
                            }
                        }
                      }
                  }, 
                  fail(res_) {
                      console.log(res_)
                  }
                })
              }
            }
        })
    },
    onShareAppMessage: function () {
        let user_id = app.db.get('element_user_id'), pid = user_id ? user_id : 0
        this.setData({
            isShow: false
        })
        console.log(pid)
        return {
            title: app.config.shop_name,
            path: '/pages/index/index?pid='+pid
        }
    }
})