const util = require('../../utils/util');
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        navbarHeight: 0,
        info: {
            portrait: '../../images/avatar.png',
            username: '',
            recommend_code: ''
        },
        config: {}
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        this.setData({
            navbarHeight: util.getNavbarHeight(),
        })
        //改变头部电量条背景色
        wx.setNavigationBarColor({
            frontColor: '#ffffff',
            backgroundColor: '#ffffff',
        });
        wx.getSystemInfo({
            success: (res) => {
                this.setData({
                    screenWidth: res.screenWidth
                });
            }
        })
        this.getUserInfo()
        this.getUploadConfig()
    },
    /**
     * 返回上一页
     */
    back() {
        wx.navigateBack({
            delta: 1,
        });
    },
    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 获取用户信息
     */
    getUserInfo: function () {
        let page = this, info = page.data.info
        app.api.getUserInfo("", function (res) {
            if (res.code > 0) {
                info.portrait = res.data.portrait
                info.username = res.data.username
                info.recommend_code = res.data.recommend_code
                page.setData({
                    info: info
                })
            } else {
                wx.showToast({
                  title: res.msg,
                  icon: 'none'
                })
            }
        })      
    },

    /**
     * 获取上传配置
     */
    getUploadConfig: function () {
        let page = this
        app.api.getUploadConfig("", function (res) {
            if (res.code > 0) {
                page.setData({
                    config: res.data
                })
            }
        })
    },

    /**
     * 上传头像
     */
    uploadImage: function () {
        let page = this, info = page.data.info, config = page.data.config
        if (!config.hasOwnProperty('policy')) {
            wx.showToast({
              title: '上传配置错误',
              icon: 'none'
            })
            return
        }
        wx.chooseImage({
            count: 1,
            sizeType: ['original', 'compressed'],
            sourceType: ['album', 'camera'],
            success(res) {
                let item = res.tempFilePaths[0];
                let key = "image/" + new Date().getTime() + Math.floor(Math.random() * 150) + '.png'
                wx.showLoading({
                    title: '上传中...',
                    icon: 'loading',
                    mask: true
                })
                wx.uploadFile({
                    url: config.host,
                    filePath: item,
                    name: 'file',
                    formData: {
                        key: key,
                        policy: config.policy, // 输入你获取的的policy
        
                        OSSAccessKeyId: config.OSSAccessKeyId, // 输入你的AccessKeyId
        
                        success_action_status: '200', // 让服务端返回200,不然，默认会返回204
        
                        signature: config.Signature, // 输入你获取的的signature
        
                    },
                    success(res) {
                        console.log(res)
                        wx.hideLoading();
                        if (res.statusCode == 200) {
                            // let data = res.data, object = JSON.parse(data);
                            // if (object.code > 0) {
                            //     info.portrait = object.data.url
                            //     page.setData({
                            //         info: info
                            //     })
                            // }
                            info.portrait = config.host + '/' + key
                            page.setData({
                                info: info
                            })
                        }
                    }
                })
            },
            fail(res) {
                wx.showToast({
                    title: '选择图片失败',
                    icon: 'none'
                })
            }
        })
    },

    /**
     * 输入昵称
     */
    setUsername: function (e) {
        let page = this, info = page.data.info
        info.username = e.detail.value
        page.setData({
            info: info
        })
    },

    /**
     * 输入推荐码
     */
    setCode: function (e) {
        let page = this, info = page.data.info
        info.recommend_code = e.detail.value
        page.setData({
            info: info
        })
    },

    /**
     * 确认修改
     */
    modifyAction: function () {
        let page = this, info = page.data.info
        if (!info.username) {
            wx.showToast({
              title: '请输入昵称',
              icon: 'none'
            })
            return
        }
        if (!info.recommend_code) {
            wx.showToast({
              title: '请输入推荐码',
              icon: 'none'
            })
            return
        }
        console.log(info)
        app.api.modifyUserInformation(info, function (res) {
            if (res.code > 0) {
                wx.showToast({
                  title: res.msg,
                })
                app.db.set('element_point_change',1)
            } else {
                wx.showToast({
                  title: res.msg,
                  icon: 'none'
                })
            }
        })
    }
})