var config = require('config.js');
var common = require('common.js');
var db = require('db.js');
//需要token才能访问的数组
var methodToken = [
    'api/User/info','api/User/detailed','api/User/staff','api/Exchange/list','api/Rule/problem','api/Commission/list','api/User/usercode','api/Rule/integral','api/Commodity/list','api/Commodity/info','api/Exchange/info','api/Commission/ratio_info','api/Commission/exchange','api/Exchange/redeem','api/Exchange/record','api/Exchange/update_status','api/User/withdrawal','api/User/updatainfo','api/feedback/add','api/invoice/add','api/User/recommend','api/Rule/balance','api/User/placeorder','api/Order/list','api/Order/info','api/Order/update','api/Order/delete','api/Order/receiving','api/Order/achievements','api/User/realname','api/User/identity_info','api/User/certificate_info','api/User/identity','api/Demand/add','api/Order/schedule','api/Order/contract','api/Order/progress','api/Order/problem','api/Rule/activity','api/User/user_identity','api/User/user_identity_edit'
];

//接口统一封装
function api(method, data, callback, show = true, isPost = true, header = {}) {
  //如果是需要登陆的，增加token
  if (methodToken.indexOf(method) >= 0) {
    var session_key = db.get('element_session_key');
// console.log('session_key: '+session_key)    
    if (!session_key) {
      common.jumpToLogin();
    } else {
      header.Authorization = session_key;
      if (isPost) {
        post(method, data, callback, show, header);
      } else {
        get(method, data, callback, show, header);
      }
    }
  } else {
    if (isPost) {
      post(method, data, callback, show, header);
    } else {
      get(method, data, callback, show, header);
    }
  }

}

//post请求
function post(method, data, callback, show, header = {}) {
console.log(config.api_url + method)  
  if (show) {
    wx.showLoading({
      title: '载入中...',
      mask: true
    });
  }
  wx.request({
    url: config.api_url + method,
    data: data,
    header: header,
    method: 'POST',
    success: function (res) {
      if (show) {
        wx.hideLoading();
      }
      //这里做判断，如果不报错就返回，如果报错，就做错误处理
      if (res.data.code >= 0) {
        callback(res.data);
      } else {
        error(res.data, callback, data);
      }
    },
    fail: function (res) {
      if (show) {
        wx.hideLoading();
      }
      return {
        status: false,
        data: res.data,
        msg: '接口调用失败',
      };
    },
    complete: function (res) {

    }
  });
}

//GET请求
function get(method, data, callback, show, header = {}) {
  // console.log(config.api_url + method + '?' + data)  
    if (show) {
      wx.showLoading({
        title: '载入中...',
        mask: true
      });
    }
    wx.request({
      url: config.api_url + method + '?' + data,
      header: header,
      method: 'GET',
      success: function (res) {
        if (show) {
          wx.hideLoading();
        }
        //这里做判断，如果不报错就返回，如果报错，就做错误处理
        callback(res.data);
      },
      fail: function (res) {
        if (show) {
          wx.hideLoading();
        }
        return {
          status: false,
          data: res.data,
          msg: '接口调用失败',
        };
      },
      complete: function (res) {
  
      }
    });
  }

//接口错误信息处理
function error(res, callback, postData) {
  switch (res.code) {
    case -100:   //token验证失败，需要从新登录
      //判断是否是需要登陆的接口
      if (methodToken.indexOf(postData.method) >= 0) {
        common.jumpToLogin();
      }
      break;
    case 2:
      ;
      break;
    default:
      callback(res);
  }
}

/**
 * 获取code后注册用户
 */
function login (data, callback) {
  api('api/login/login', data, function (res) {
    callback(res)
  })
}

/**
 * 用户授权
 */
function register(data, callback) {
  api('login.register', data, function (res) {
    callback(res)
  })
}

/**
 * 获取首页轮播图
 */
function getIndexBanner (data, callback) {
  api('api/Index/banner', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 获取首页分类
 */
function getIndexCategory (data, callback) {
  api('api/Index/service_category', data, function (res) {
    callback(res)
  })
}

/**
 * 获取首页服务列表
 */
function getIndexServiceList (data, callback) {
  api('api/Index/service_list', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 获取更多分类服务列表
 */
function getcateServiceList (data, callback) {
  api('api/Commodity/list', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 获取服务详情信息
 */
function getServiceDetail (data, callback) {
  api('api/Commodity/info', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 获取佣金兑换数据
 */
function getCommissionExchangeData (data, callback) {
  api('api/Commission/ratio_info', data, function (res) {
    callback(res)
  })
}

/**
 * 积分兑换操作
 */
function commissionExchangeAction (data, callback) {
  api('api/Commission/exchange', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 获取用户信息
 */
function getUserInfo (data, callback) {
  api('api/User/info', data, function (res) {
    callback(res)
  })
}

/**
 * 余额明细
 */
function usersBalanceList (data, callback) {
  api('api/User/detailed', data, function (res) {
    callback(res)
  })
}

/**
 * 申请成为正式员工
 */
function applyStaff (data, callback) {
  api('api/User/staff', data, function (res) {
    callback(res)
  })
}

/**
 * 积分商城
 */
function getIntegralMallList (data, callback) {
  api('api/Exchange/list', data, function (res) {
    callback(res)
  })
}

/**
 * 积分商城产品详情
 */
function getIntegralMallDetail (data, callback) {
  api('api/Exchange/info', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 积分兑换操作
 */
function integralMallExchangeAction (data, callback) {
  api('api/Exchange/redeem', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 兑换记录
 */
function userIntegralMallExchangeRecords (data, callback) {
  api('api/Exchange/record', data, function (res) {
    callback(res)
  },true, false)
}

/**
 * 确认收货
 */
function integralMallConfirmShouHUo (data, callback) {
  api('api/Exchange/update_status', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 常见问题
 */
function getSolutionList (data, callback) {
  api('api/Rule/problem', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 积分明细
 */
function getPointList (data, callback) {
  api('api/Commission/list', data, function (res) {
    callback(res)
  })
}

/**
 * 邀请海报
 */
function getUserInvitePoster (data, callback) {
  api('api/User/usercode', data, function (res) {
    callback(res)
  })
}

/**
 * 获取积分规则
 */
function getIntegralRule (data, callback) {
  api('api/Rule/integral', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 发送短信验证码
 */
function senSmsCode (data, callback) {
  api('api/Login/send_sms', data, function (res) {
    callback(res)
  })
}

/**
 * 余额提现
 */
function userBalanceWithdraw (data, callback) {
  api('api/User/withdrawal', data, function (res) {
    callback(res)
  })
}

/**
 * 修改用户信息
 */
function modifyUserInformation (data, callback) {
  api('api/User/updatainfo', data, function (res) {
    callback(res)
  })
}

/**
 * 用户反馈
 */
function userFeedQuestion (data, callback) {
  api('api/feedback/add', data, function (res) {
    callback(res)
  })
}

/**
 * 添加发票
 */
function userInvoiceAdd (data, callback) {
  api('api/invoice/add', data, function (res) {
    callback(res)
  })
}

/**
 * 获取用户推荐信息
 */
function getUserRecommnedInfo (data, callback) {
  api('api/User/recommend', data, function (res) {
    callback(res)
  })
}

/**
 * 用户余额规则
 */
function getUserBalanceRule (data, callback) {
  api('api/Rule/balance', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 活动规则 
 */
function getUserActivityRule (data, callback) {
  api('api/Rule/activity', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 获取上传配置
 */
function getUploadConfig (data, callback) {
  api('api/Upload/getSignedUrl', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 用户服务下单
 */
function userServiceCreateOrder (data, callback) {
  api('api/User/placeorder', data, function (res) {
    callback(res)
  })
}

/**
 * 获取用户订单列表
 */
function getUserOrderList (data, callback) {
  api('api/Order/list',data, function (res) {
    callback(res)
  })
}

/**
 * 获取订单详情
 */
function getUserOrderDetail (data, callback) {
  api('api/Order/info', data, function (res) {
    callback(res)
  })
}

/**
 * 修改订单状态
 */
function changeOrderStatus (data, callback) {
  api('api/Order/update', data, function (res) {
    callback(res)
  })
}

/**
 * 删除订单
 */
function userOrderDel (data, callback) {
  api('api/Order/delete', data, function (res) {
    callback(res)
  })
}

/**
 * 确认收货
 */
function orderConfirmShouHuo (data, callback) {
  api('api/Order/receiving', data, function (res) {
    callback(res)
  })
}

/**
 * 查看成果
 */
function orderLookResult (data, callback) {
  api('api/Order/achievements', data, function (res) {
    callback(res)
  })
}

/**
 * 查看合同
 */
function orderCheckContact (data, callback) {
  api('api/Order/contract', data, function (res) {
    callback(res)
  })
}

/**
 * 实名认证操作
 */
function realNameAuthAction (data, callback) {
  api('api/User/realname', data, function (res) {
    callback(res)
  })
}

/**
 * 获取身份信息
 */
function getAuthIdentityInfo (data, callback) {
  api('api/User/identity_info', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 获取证件信息
 */
function getCertInfo (data, callback) {
  api('api/User/certificate_info', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 身份认证操作
 */
function userIdentityAuthAction (data, callback) {
  api('api/User/identity', data, function (res) {
    callback(res)
  })
}

/**
 * 发布需求
 */
function addDemand (data, callback) {
  api('api/Demand/add', data, function (res) {
    callback(res)
  })
}

/**
 * 订单催进度
 * 
 */
function orderSchedule (data, callback) {
  api('api/Order/schedule', data, function (res) {
    callback(res)
  })
}

/**
 * 查看订单历史记录
 */
function checkOrderHistoryRecords (data, callback) {
  api('api/Order/progress', data, function (res) {
    callback(res)
  })
}

/**
 * 订单问题反馈
 */
function orderFeedQuestion (data, callback) {
  api('api/Order/problem', data, function (res) {
    callback(res)
  })
}

/**
 * 获取用户身份信息
 */
function getUserIdentifyInfo (data, callback) {
  api('api/User/user_identity', data, function (res) {
    callback(res)
  }, true, false)
}

/**
 * 修改用户认证信息
 */
function userAuthDataModifyOnlyABle (data, callback) {
  api('api/User/user_identity_edit', data, function (res) {
    callback(res)
  })
}

module.exports = {
  login,register,getIndexBanner,getIndexCategory,getUserInfo,usersBalanceList,applyStaff,getIntegralMallList,getSolutionList,getPointList,getUserInvitePoster,getIntegralRule,senSmsCode,getIndexServiceList,getcateServiceList,getServiceDetail,getIntegralMallDetail,getCommissionExchangeData,commissionExchangeAction,integralMallExchangeAction,userIntegralMallExchangeRecords,integralMallConfirmShouHUo,userBalanceWithdraw,modifyUserInformation,userFeedQuestion,userInvoiceAdd,getUserRecommnedInfo,getUserBalanceRule,getUploadConfig,userServiceCreateOrder,getUserOrderList,getUserOrderDetail,changeOrderStatus,userOrderDel,orderConfirmShouHuo,orderLookResult,realNameAuthAction,getAuthIdentityInfo,getCertInfo,userIdentityAuthAction,addDemand,orderSchedule,orderCheckContact,checkOrderHistoryRecords,orderFeedQuestion,getUserActivityRule,getUserIdentifyInfo,userAuthDataModifyOnlyABle
}