var common = require('common.js');
/**
 * wxUserInfo     微信的用户信息，只有登录了之后，才有
 * userToken      用户token，用于判断是否登录
 * indexSlider    首页幻灯片数据
 * indexRecommend 首页店铺推荐
 * indexHotGoods  首页热卖商品
 */

//取值
function get(key) {
  try {
    return wx.getStorageSync(key);
  } catch (e) {
    return false;
  }
}

//赋值
function set(key, value, sync = false) {
  try {
    if (sync) {
      return wx.setStorageSync(key, value);
    } else {
      wx.setStorage({
        key: key,
        data: value
      });
    }
  } catch (e) {

  }
}

//移除
function del(key, sync = false) {
  try {
    if (sync) {
      return wx.removeStorageSync(key);
    } else {
      wx.removeStorage({
        key: key
      });
    }
  } catch (e) {
    return false;
  }
}

//清空
function clear(sync = false) {
  try {
    if (sync) {
      return wx.clearStorageSync();
    } else {
      wx.clearStorage();
    }
  } catch (e) {
    return false;
  }
}

//获取用户token，如果缓存有，直接返回，如果没有，就先微信登陆，然后服务器登陆，最后返回token
function userToken(callback) {
  var token = get('userToken');
  if (token) {
    callback(token);
  } else {
    //如果没有登陆，就去登陆
    common.jumpToLogin();
  }
}

module.exports = {
  get: get,
  set: set,
  del: del,
  clear: clear,
  userToken: userToken
}